DStv Self Service | Self Service
Description: Manage your DStv account online, easily clear error codes from your PC, find an answer to frequently asked questions, learn more about your decoder and what packages are on offer.
Keywords: dstv self service, self service for dstv, dstv help, help with dstv, manage dstv, dstv account, dstv care, dstv customer care, multichoice customer care

Loading Menu
Login Forgot Password? Register
Menu
﻿

- Big Brother Hotshots
- Latest News
- Hottest Videos
- Vote for your favourite

Get your DStv Explora

## Clear Error Codes
South African customers only

Smartcard/Serial No.
Surname
Error Codes
Scam Alert
Please be aware of these scams that have been brought to our attention.
DStv Debit Order
Win with DStv by switching to Debit Order
Repeats on DStv
Explanations regarding repeats and DStv's programming schedule.

### COMMON FAQ'S

#### Common questions asked

- How do I pay my DStv Account?
- What is XtraView?
- What is Decoder Care Contract (DCC)?
- What is DStv Catch Up?

View all FAQ's

### COMMON ERROR CODES

#### Explanations on common Error Codes

- E04 - Please insert Smartcard
- E16 - Service currently scrambled
- E17 - Smartcard marriage conflict
- E37 - Invalid channel number

View all Error Codes

### HOW TO ...

#### All your DStv how to’s

- Setting up Parental Control
- Viewing the MultiChoice Ts & Cs
- Installing Drifta on your PC
- Deleting the Playlist on HD PVR

View all How Tos

### Packages

- DStv Premium
- DStv Compact
- DStv Family
- DStv Access
- DStv Portuguesa

View all Packages

### Services

- DStv Mobile
- Holiday Viewing
- DStv Catch Up
- XtraView
- BoxOffice

View all Services

### Decoders

View all Decoders
© 2011 MultiChoice (PTY) LTD. All rights reserved.
MultiChoice Website | Terms & Conditions | Privacy Policy | Copyright | Announcements | Site Map | DMMA | Contact us
x

### Login

#### Login with your DStv Connect details

Enter your email address / username Enter your password Forgot your password?
Don't have an account?
>>
Register
logging you in ...
x

### Forgot Password

Enter your registered email address
x

### Register

#### Create your DStv Connect account

This will allow you to login to all DStv websites & applications

Enter your email address Enter a password

Strength:

See password I accept the terms & conditions Please accept terms & conditions.
Already have an account?
>>
Login
Processing ...

### Verification email sent

#### Thank you for signing up!

A verification link has been sent to your email.
x

### Email Reset

We see you have changed your email address.
Please click on the verification link you have been emailed to reactivate your DStv Connect account.